@@ -4,6 +4,12 @@ use strict;
 use warnings;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-02-18'; # DATE
+our $DIST = 'Text-Wrap-NoStrip'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 our @EXPORT_OK = qw(
                        wrap
                );
@@ -71,7 +77,7 @@ Text::Wrap::NoStrip - Line wrapping without stripping the whitespace
 
 =head1 VERSION
 
-This document describes version 0.002 of Text::Wrap::NoStrip (from Perl distribution Text-Wrap-NoStrip), released on 2023-02-18.
+This document describes version 0.003 of Text::Wrap::NoStrip (from Perl distribution Text-Wrap-NoStrip), released on 2023-02-18.
 
 =head1 SYNOPSIS
 
